@@ -9,8 +9,10 @@
 # exit script on error
 set -e 
 
-# build pgRouting
-cmake  -DPOSTGRESQL_VERSION=$POSTGRESQL_VERSION
+# build osm2pgrouting
+mkdir build
+cd build
+cmake .. 
 make
 sudo make install
-
+cd ..
